@@ -1,7 +1,7 @@
-`summary.cca` <-
-    function (object, scaling = 2, axes = 6, display=c("sp","wa","lc","bp","cn"), 
-              digits = max(3, getOption("digits") - 3), ...) 
-{
+`summary.cca` <- function (object, scaling = "species", axes = 6,
+                           display=c("sp","wa","lc","bp","cn"),
+                           digits = max(3, getOption("digits") - 3),
+                           correlation = FALSE, hill = FALSE, ...) {
     if (inherits(object, "pcaiv")) {
         warning("this is an ade4 object which vegan cannot handle")
         axes <- min(axes, object$nf)
@@ -9,8 +9,12 @@
     }
     axes <- min(axes, sum(object$CCA$rank, object$CA$rank))
     summ <- list()
-    if (axes && length(display) && (!is.na(display) && !is.null(display))) 
-        summ <- scores(object, scaling = scaling, choices = 1:axes, display = display, ...)
+    ## scaling is stored in return object so must be in numeric format
+    scaling <- scalingType(scaling = scaling, correlation = correlation,
+                           hill = hill)
+    if (axes && length(display) && (!is.na(display) && !is.null(display)))
+        summ <- scores(object, scaling = scaling, choices = 1:axes, display = display,
+                       ...)
     ## scores() drops list to a matrix if there is only one item: workaround below.
     if (!is.list(summ) && length(display) == 1) {
         nms <- c("species", "sites", "constraints", "biplot", "centroids")
@@ -35,7 +39,7 @@
     summ$constr.chi <- object$CCA$tot.chi
     summ$unconst.chi <- object$CA$tot.chi
     summ$cont <- summary(eigenvals(object))
-    if (!is.null(object$CCA))
+    if (!is.null(object$CCA) && object$CCA$rank > 0)
         summ$concont <- summary(eigenvals(object, constrained = TRUE))
     summ$ev.head <- c(summ$ev.con, summ$ev.uncon)[seq_len(axes)]
     summ$scaling <- scaling
